@@ -24,11 +24,13 @@
 #include <glib-object.h>
 
 #include <gconf/gconf.h>
+#include <gconf/gconf-client.h>
 
 #define GCONF_TYPE_VALUE (gconf_value_get_type ())
 
 GType gconf_value_get_type (void);
 gchar *gconf_get_key_name_from_path (const gchar *path);
 gchar *gconf_value_type_to_string (GConfValueType value_type);
+GConfSchema *gconf_client_get_schema_for_key (GConfClient *client, const char *key);
 
 #endif /* __GCONF_UTIL_H__ */
